summaryrefslogtreecommitdiffstats
path: root/module/plugins/PluginManager.py
diff options
context:
space:
mode:
Diffstat (limited to 'module/plugins/PluginManager.py')
-rw-r--r--module/plugins/PluginManager.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/module/plugins/PluginManager.py b/module/plugins/PluginManager.py
index 733cd2c5d..f42bd08c6 100644
--- a/module/plugins/PluginManager.py
+++ b/module/plugins/PluginManager.py
@@ -221,7 +221,7 @@ class PluginManager:
def parseUrls(self, urls):
"""parse plugins for given list of urls, seperate to crypter and hoster"""
res = {"hoster": [], "crypter": []} # tupels of (url, plugin)
@@ -313,7 +313,7 @@ class PluginManager:
def find_module(self, fullname, path=None):
#redirecting imports if necesarry
- if fullname.startswith(self.ROOT) or fullname.startswith(self.USERROOT): #seperate pyload plugins
+ if fullname.startswith(self.ROOT) or fullname.startswith(self.USERROOT): #separate pyload plugins
if fullname.startswith(self.USERROOT): user = 1
else: user = 0 #used as bool and int
@@ -221,7 +221,7 @@ class PluginManager:
def parseUrls(self, urls):
- """parse plugins for given list of urls, seperate to crypter and hoster"""
+ """parse plugins for given list of urls, separate to crypter and hoster"""
res = {"hoster": [], "crypter": []} # tupels of (url, plugin)